package com.unissoft.utils;

import javax.servlet.http.HttpServletRequest;

/**
 * @author qingsong.han
 * @description: 获取ip工具类
 * @create 2021-10-21 15:56
 */
public class IPUtils {
    /**
     * 获取IP地址
     * <p>
     * 使用Nginx等反向代理软件， 则不能通过request.getRemoteAddr()获取IP地址
     * 1.在代理nginx中配置,真实ip转发:示例
     *location /smart-grp-basic {
     * 	proxy_pass http://172.16.0.6:8071/;
     * 	# 使用转发真实ip到请求
     * 	proxy_set_header Host                $host;
     * 	proxy_set_header X-Real-IP           $remote_addr;
     * 	proxy_set_header X-Forwarded-For     $proxy_add_x_forwarded_for;
     * 	proxy_set_header X-Forwarded-Proto   $scheme;
     * 	proxy_redirect   off;
     * }
     *
     * 2.配置文件
     *
     * 如果使用了多级反向代理的话，X-Forwarded-For的值并不止一个，而是一串IP地址，X-Forwarded-For中第一个非unknown的有效IP字符串，则为真实IP地址
     */
    public static String getRemoteIP(HttpServletRequest request) {

        String ip = request.getHeader("x-forwarded-for");
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        return "0:0:0:0:0:0:0:1".equals(ip) ? "127.0.0.1" : ip;
    }
}
